FAQ: General — Transifex v0.8.0 documentation

# Transifex v0.8.0 documentation

# FAQ: General

## Why does this project exist?

## What does “Transifex” mean, and how do you pronounce it?

## Who’s behind this?

## Which sites use Django?

## <L10n Platform X> does <feature Y> – why doesn’t Transifex?

## Is Transifex a complete Localization platform?

## How can I download the Transifex documentation to read it offline?

The Transifex docs are available in the `docs` directory of each Transifex tarball release. These docs are in ReST (ReStructured Text) format, and each text file corresponds to a Web page on the official Django site.

Because the documentation is stored in revision control, you can browse documentation changes just like you can browse code changes.

Technically, the docs on Transifex’s site are generated from the latest development versions of those ReST documents, so the docs on the Transifex site may offer more information than the docs that come with the latest Transifex release.